==> wiki3_4_3.zip: wiki3_4_3/plugin/core/Include.pm <==
######################################################################
#
# ꤷڡ⤷ϻڡλѥ饰դ򥤥󥯥롼ɤޤ
# ڡΤ򥤥󥯥롼ɤϰ˥ڡ̾ꤷޤ
# <pre>
# {{include ڡ̾}}
# </pre>
# ڡΥѥ饰դ򥤥󥯥롼ɤ
# ڡ̾³裲˥ѥ饰̾ꤷޤ
# <pre>
# {{include ڡ̾,ѥ饰̾}}
# </pre>
#
######################################################################
package plugin::core::Include;
#use strict;

#=====================================================================
# 󥹥ȥ饯
#=====================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#=====================================================================
# 饤ؿ
#=====================================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $page = shift;
	my $para = shift;
	my $cgi  = $wiki->get_CGI;
	
	if(!$wiki->page_exists($page)){
		return &Util::error("ڡ¸ߤޤ");
	}
	if($page eq $cgi->param("page")){
		return &Util::error("ƱΥڡincludeǤޤ");
	}
	foreach my $incpage (@{$self->{stack}}){
		if($incpage eq $page){
			return &Util::error("ƱΥڡincludeǤޤ");
		}
	}
	
	my $source = $wiki->get_page($page);
	
	$para = quotemeta(Util::trim($para));
	if($para ne ""){
		if($source =~ /(\n|^)!!!\s*$para((.|\s|\r|\n)*?)\s*(\n!!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!!\s*$para((.|\s|\r|\n)*?)\s*(\n!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!\s*$para((.|\s|\r|\n)*?)\s*(\n!|$)/){
			$source = $2;
		} else {
			return &Util::error("ѥ饰դ¸ߤޤ");
		}
	}
	
	# åˤĤ
	push(@{$self->{stack}},$page);
	
	my $pagetmp = $cgi->param("page");
	$cgi->param("page",$page);
	my $result = $wiki->process_wiki($source);
	$cgi->param("page",$pagetmp);
	
	# å
	pop(@{$self->{stack}});
	
	return $result;
}

1;

==> wiki3_5_0.zip: wiki3_5_0/plugin/core/Include.pm <==
######################################################################
#
# ꤷڡ⤷ϻڡλѥ饰դ򥤥󥯥롼ɤޤ
# ڡΤ򥤥󥯥롼ɤϰ˥ڡ̾ꤷޤ
# <pre>
# {{include ڡ̾}}
# </pre>
# ڡΥѥ饰դ򥤥󥯥롼ɤ
# ڡ̾³裲˥ѥ饰̾ꤷޤ
# <pre>
# {{include ڡ̾,ѥ饰̾}}
# </pre>
#
######################################################################
package plugin::core::Include;
#use strict;

#=====================================================================
# 󥹥ȥ饯
#=====================================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#=====================================================================
# ѥ饰մؿ
#=====================================================================
sub paragraph {
	my $self   = shift;
	my $wiki   = shift;
	my $page   = shift;
	my $para   = shift;
	my $cgi    = $wiki->get_CGI;
	
	if(!$wiki->page_exists($page)){
		return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
	}
	if(!$wiki->can_show($page)){
		return &Util::paragraph_error("ڡλȸ¤ޤ","WIKI");
	}
	if($page eq $cgi->param("page")){
		return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
	}
	foreach my $incpage (@{$self->{stack}}){
		if($incpage eq $page){
			return &Util::paragraph_error("ƱΥڡincludeǤޤ","WIKI");
		}
	}
	
	my $source = $wiki->get_page($page);
	
	$para = quotemeta(Util::trim($para));
	if($para ne ""){
		if($source =~ /(\n|^)!!!\s*$para((.|\s|\r|\n)*?)\s*(\n!!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!!\s*$para((.|\s|\r|\n)*?)\s*(\n!!|$)/){
			$source = $2;
		} elsif($source =~ /(\n|^)!\s*$para((.|\s|\r|\n)*?)\s*(\n!|$)/){
			$source = $2;
		} else {
			return &Util::paragraph_error("ڡ¸ߤޤ","WIKI");
		}
	}
	
	# åˤĤ
	push(@{$self->{stack}},$page);
	
	# ä΢
	my $pagetmp = $cgi->param("page");
	$cgi->param("page",$page);
	$self->{parser}->parse($source);
	$cgi->param("page",$pagetmp);
	
	# å
	pop(@{$self->{stack}});
	
	return undef;
}

1;
